==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Snap_rounding_2/group__PkgSnapRounding2Concepts.js <==
var group__PkgSnapRounding2Concepts =
[
    [ "SnapRoundingTraits_2", "classSnapRoundingTraits__2.html", [
      [ "Cartesian_const_iterator_2", "classSnapRoundingTraits__2.html#a5a2eb027ae79905194171906edb3c608", null ],
      [ "Compare_x_2", "classSnapRoundingTraits__2.html#a364a16e3f094f27590cf7836796c87d9", null ],
      [ "Compare_y_2", "classSnapRoundingTraits__2.html#a9a02cc43e2f5a360f617034fcbe54b22", null ],
      [ "Construct_cartesian_const_iterator_2", "classSnapRoundingTraits__2.html#abb065b0bd803d7f522ad4895049b0f49", null ],
      [ "Construct_iso_rectangle_2", "classSnapRoundingTraits__2.html#a01c718b1e9bc41dcf7254b7ed5ff053b", null ],
      [ "Construct_max_vertex_2", "classSnapRoundingTraits__2.html#afb35e8b1b2fb82c12e8074b9daa8f76e", null ],
      [ "Construct_min_vertex_2", "classSnapRoundingTraits__2.html#ac54cd7362200a51ba43faa0b1162d85e", null ],
      [ "Construct_segment_2", "classSnapRoundingTraits__2.html#afc288eb1c80674bcba661418c455265d", null ],
      [ "Construct_vertex_2", "classSnapRoundingTraits__2.html#a23cee7b57ee6023992521884b26130cd", null ],
      [ "FT", "classSnapRoundingTraits__2.html#a5f68dcd59ba1b37bd7bbe750ceeb5565", null ],
      [ "Integer_grid_point_2", "classSnapRoundingTraits__2.html#ad3935791fdfcf4b92e45be570d7fb0ba", null ],
      [ "Iso_rectangle_2", "classSnapRoundingTraits__2.html#af2e0eb028a5571f8aef133c5d339146e", null ],
      [ "Minkowski_sum_with_pixel_2", "classSnapRoundingTraits__2.html#a0651c2e5f7603dd728631d41f706159b", null ],
      [ "Point_2", "classSnapRoundingTraits__2.html#afbae70152d83aaeaa4bf944e5fcedbba", null ],
      [ "Segment_2", "classSnapRoundingTraits__2.html#aa5c9467f6da4abc080ec8f03c527cdce", null ],
      [ "Snap_2", "classSnapRoundingTraits__2.html#a66d05d22b80334119bc503b53d7a9c24", null ],
      [ "To_double", "classSnapRoundingTraits__2.html#a048a06eaccae37a827cab307d46ad2f7", null ],
      [ "compare_x_2_object", "classSnapRoundingTraits__2.html#ae415d3c1164f731a393ee312b28b210b", null ],
      [ "compare_y_2_object", "classSnapRoundingTraits__2.html#a6fc1222c66b348f2b6951e82e5b7478b", null ],
      [ "construct_iso_rectangle_2_object", "classSnapRoundingTraits__2.html#a5d7c693fe72d200a7cb2ed6888b8cb84", null ],
      [ "construct_segment_2_object", "classSnapRoundingTraits__2.html#a55c9ad615e1971cd5a67c78e47372878", null ],
      [ "construct_vertex_2_object", "classSnapRoundingTraits__2.html#a1100e19a6474189e215f8db6f2f072c5", null ],
      [ "integer_grid_point_2_object", "classSnapRoundingTraits__2.html#a219eb29f12e5c1014e3303f13176b40b", null ],
      [ "minkowski_sum_with_pixel_2_object", "classSnapRoundingTraits__2.html#afe9c36e6e494472738a890a019b84ffb", null ],
      [ "snap_2_object", "classSnapRoundingTraits__2.html#a0a0727beed868253d53acfc023086218", null ]
    ] ],
    [ "IsoRectangle_2", "classSRTraits__2_1_1IsoRectangle__2.html", null ],
    [ "ConstructVertex_2", "classSRTraits__2_1_1ConstructVertex__2.html", [
      [ "operator()", "classSRTraits__2_1_1ConstructVertex__2.html#a54d74037f05711e26a9aadf57fa5fc95", null ]
    ] ],
    [ "ConstructSegment_2", "classSRTraits__2_1_1ConstructSegment__2.html", [
      [ "operator()", "classSRTraits__2_1_1ConstructSegment__2.html#a0d2bb3568958ea381007ab10ccb8f010", null ]
    ] ],
    [ "ConstructIsoRectangle_2", "classSRTraits__2_1_1ConstructIsoRectangle__2.html", [
      [ "operator()", "classSRTraits__2_1_1ConstructIsoRectangle__2.html#a9a6cd49cba68fedfa6ee4e11a8ea3092", null ]
    ] ],
    [ "CompareX_2", "classSRTraits__2_1_1CompareX__2.html", null ],
    [ "CompareY_2", "classSRTraits__2_1_1CompareY__2.html", null ],
    [ "Snap_2", "classSRTraits__2_1_1Snap__2.html", null ],
    [ "IntegerGridPoint_2", "classSRTraits__2_1_1IntegerGridPoint__2.html", null ],
    [ "MinkowskiSumWithPixel_2", "classSRTraits__2_1_1MinkowskiSumWithPixel__2.html", [
      [ "operator()", "classSRTraits__2_1_1MinkowskiSumWithPixel__2.html#ab2bcfa5a7a774564001b1788a27116be", null ]
    ] ]
];

==> CGAL-6.0-doc_html.tar.xz: doc_html/Snap_rounding_2/group__PkgSnapRounding2Concepts.js <==
var group__PkgSnapRounding2Concepts =
[
    [ "SnapRoundingTraits_2", "classSnapRoundingTraits__2.html", [
      [ "Cartesian_const_iterator_2", "classSnapRoundingTraits__2.html#a5a2eb027ae79905194171906edb3c608", null ],
      [ "Compare_x_2", "classSnapRoundingTraits__2.html#a364a16e3f094f27590cf7836796c87d9", null ],
      [ "Compare_y_2", "classSnapRoundingTraits__2.html#a9a02cc43e2f5a360f617034fcbe54b22", null ],
      [ "Construct_cartesian_const_iterator_2", "classSnapRoundingTraits__2.html#abb065b0bd803d7f522ad4895049b0f49", null ],
      [ "Construct_iso_rectangle_2", "classSnapRoundingTraits__2.html#a01c718b1e9bc41dcf7254b7ed5ff053b", null ],
      [ "Construct_max_vertex_2", "classSnapRoundingTraits__2.html#afb35e8b1b2fb82c12e8074b9daa8f76e", null ],
      [ "Construct_min_vertex_2", "classSnapRoundingTraits__2.html#ac54cd7362200a51ba43faa0b1162d85e", null ],
      [ "Construct_segment_2", "classSnapRoundingTraits__2.html#afc288eb1c80674bcba661418c455265d", null ],
      [ "Construct_vertex_2", "classSnapRoundingTraits__2.html#a23cee7b57ee6023992521884b26130cd", null ],
      [ "FT", "classSnapRoundingTraits__2.html#a5f68dcd59ba1b37bd7bbe750ceeb5565", null ],
      [ "Integer_grid_point_2", "classSnapRoundingTraits__2.html#ad3935791fdfcf4b92e45be570d7fb0ba", null ],
      [ "Iso_rectangle_2", "classSnapRoundingTraits__2.html#af2e0eb028a5571f8aef133c5d339146e", null ],
      [ "Minkowski_sum_with_pixel_2", "classSnapRoundingTraits__2.html#a0651c2e5f7603dd728631d41f706159b", null ],
      [ "Point_2", "classSnapRoundingTraits__2.html#afbae70152d83aaeaa4bf944e5fcedbba", null ],
      [ "Segment_2", "classSnapRoundingTraits__2.html#aa5c9467f6da4abc080ec8f03c527cdce", null ],
      [ "Snap_2", "classSnapRoundingTraits__2.html#a66d05d22b80334119bc503b53d7a9c24", null ],
      [ "To_double", "classSnapRoundingTraits__2.html#a048a06eaccae37a827cab307d46ad2f7", null ],
      [ "compare_x_2_object", "classSnapRoundingTraits__2.html#ae415d3c1164f731a393ee312b28b210b", null ],
      [ "compare_y_2_object", "classSnapRoundingTraits__2.html#a6fc1222c66b348f2b6951e82e5b7478b", null ],
      [ "construct_iso_rectangle_2_object", "classSnapRoundingTraits__2.html#a5d7c693fe72d200a7cb2ed6888b8cb84", null ],
      [ "construct_segment_2_object", "classSnapRoundingTraits__2.html#a55c9ad615e1971cd5a67c78e47372878", null ],
      [ "construct_vertex_2_object", "classSnapRoundingTraits__2.html#a1100e19a6474189e215f8db6f2f072c5", null ],
      [ "integer_grid_point_2_object", "classSnapRoundingTraits__2.html#a219eb29f12e5c1014e3303f13176b40b", null ],
      [ "minkowski_sum_with_pixel_2_object", "classSnapRoundingTraits__2.html#afe9c36e6e494472738a890a019b84ffb", null ],
      [ "snap_2_object", "classSnapRoundingTraits__2.html#a0a0727beed868253d53acfc023086218", null ]
    ] ],
    [ "SRTraits_2::IsoRectangle_2", "classSRTraits__2_1_1IsoRectangle__2.html", null ],
    [ "SRTraits_2::ConstructVertex_2", "classSRTraits__2_1_1ConstructVertex__2.html", [
      [ "operator()", "classSRTraits__2_1_1ConstructVertex__2.html#a54d74037f05711e26a9aadf57fa5fc95", null ]
    ] ],
    [ "SRTraits_2::ConstructSegment_2", "classSRTraits__2_1_1ConstructSegment__2.html", [
      [ "operator()", "classSRTraits__2_1_1ConstructSegment__2.html#a0d2bb3568958ea381007ab10ccb8f010", null ]
    ] ],
    [ "SRTraits_2::ConstructIsoRectangle_2", "classSRTraits__2_1_1ConstructIsoRectangle__2.html", [
      [ "operator()", "classSRTraits__2_1_1ConstructIsoRectangle__2.html#a9a6cd49cba68fedfa6ee4e11a8ea3092", null ]
    ] ],
    [ "SRTraits_2::CompareX_2", "classSRTraits__2_1_1CompareX__2.html", null ],
    [ "SRTraits_2::CompareY_2", "classSRTraits__2_1_1CompareY__2.html", null ],
    [ "SRTraits_2::Snap_2", "classSRTraits__2_1_1Snap__2.html", null ],
    [ "SRTraits_2::IntegerGridPoint_2", "classSRTraits__2_1_1IntegerGridPoint__2.html", null ],
    [ "SRTraits_2::MinkowskiSumWithPixel_2", "classSRTraits__2_1_1MinkowskiSumWithPixel__2.html", [
      [ "operator()", "classSRTraits__2_1_1MinkowskiSumWithPixel__2.html#ab2bcfa5a7a774564001b1788a27116be", null ]
    ] ]
];
